package alternatenames;

import com.adbs.querybuilder.*;
import com.adbs.syntax.*;
import javax.swing.JOptionPane;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.BufferedReader;
import java.util.logging.Level;
import java.util.logging.Logger;

public class MainFrame extends javax.swing.JFrame
{
	private static final long serialVersionUID = 1L;

	private PlainTextSQLBuilder plainTextSQLBuilder1 = new PlainTextSQLBuilder();
	private PlainTextSQLBuilder plainTextSQLBuilder2 = new PlainTextSQLBuilder();

    public MainFrame()
	{
        initComponents();

		// center window on the desktop
		setLocationRelativeTo(null);

		// set required syntax provider
		queryBuilder1.setSyntaxProvider(new DB2SyntaxProvider());

		//set up SQL builders:
		plainTextSQLBuilder1.setQueryBuilder(queryBuilder1);
		plainTextSQLBuilder1.setUseAltNames(true);
		plainTextSQLBuilder2.setQueryBuilder(queryBuilder1);
		plainTextSQLBuilder2.setUseAltNames(false);

		// handle the notification from plainTextSQLBuilder1 about the query text has been changed
		plainTextSQLBuilder1.addSQLUpdatedEventListener(new SQLUpdatedEventListener()
		{
			@Override
			public void sqlUpdatedEventOccurred(SQLUpdatedEvent event)
			{
				try
				{
					jTextPane1.setText(plainTextSQLBuilder1.getSQL());
				}
				catch (QueryBuilderException ex)
				{
					Logger.getLogger(MainFrame.class.getName()).log(Level.SEVERE, null, ex);
				}
			}
		});

		// handle the notification from plainTextSQLBuilder2 about the query text has been changed
		plainTextSQLBuilder2.addSQLUpdatedEventListener(new SQLUpdatedEventListener()
		{
			@Override
			public void sqlUpdatedEventOccurred(SQLUpdatedEvent event)
			{
				try
				{
					jTextPane2.setText(plainTextSQLBuilder2.getSQL());
				}
				catch (QueryBuilderException ex)
				{
					Logger.getLogger(MainFrame.class.getName()).log(Level.SEVERE, null, ex);
				}
			}
		});

		// Load metadata from XML file located in resources (for demonstration purposes)
		try
		{
			Class resourceClass = MainFrame.class;
			InputStream stream = resourceClass.getResourceAsStream("db2_sample_with_alt_names.xml");
			BufferedReader br = new BufferedReader(new InputStreamReader(stream));
			StringBuilder sb = new StringBuilder();
			String line = null;

			while ((line = br.readLine()) != null)
			{
				sb.append(line + "\n");
			}

			br.close();
			queryBuilder1.getMetadataContainer().loadFromXML(sb.toString());
		}
		catch (Exception ex)
		{
			Logger.getLogger(this.getClass().getName()).log(Level.SEVERE, null, ex);
			JOptionPane.showMessageDialog(this, ex.getMessage());
		}
    }

    @SuppressWarnings("unchecked")
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        jSplitPane1 = new javax.swing.JSplitPane();
        queryBuilder1 = new com.adbs.querybuilder.QueryBuilder();
        jTabbedPane1 = new javax.swing.JTabbedPane();
        jScrollPane1 = new javax.swing.JScrollPane();
        jTextPane1 = new javax.swing.JTextPane();
        jScrollPane2 = new javax.swing.JScrollPane();
        jTextPane2 = new javax.swing.JTextPane();
        jMenuBar1 = new javax.swing.JMenuBar();
        jMenu1 = new javax.swing.JMenu();
        jMenuItemEditMetadata = new javax.swing.JMenuItem();

        setDefaultCloseOperation(javax.swing.WindowConstants.EXIT_ON_CLOSE);
        setTitle("AlternateNames Demo");
        getContentPane().setLayout(new javax.swing.BoxLayout(getContentPane(), javax.swing.BoxLayout.LINE_AXIS));

        jSplitPane1.setDividerLocation(350);
        jSplitPane1.setOrientation(javax.swing.JSplitPane.VERTICAL_SPLIT);
        jSplitPane1.setResizeWeight(1.0);
        jSplitPane1.setLeftComponent(queryBuilder1);

        jTextPane1.addFocusListener(new java.awt.event.FocusAdapter() {
            public void focusLost(java.awt.event.FocusEvent evt) {
                jTextPane1FocusLost(evt);
            }
        });
        jScrollPane1.setViewportView(jTextPane1);

        jTabbedPane1.addTab("Query text with alternate object names", jScrollPane1);

        jTextPane2.addFocusListener(new java.awt.event.FocusAdapter() {
            public void focusLost(java.awt.event.FocusEvent evt) {
                jTextPane2FocusLost(evt);
            }
        });
        jScrollPane2.setViewportView(jTextPane2);

        jTabbedPane1.addTab("Query text with real object names", jScrollPane2);

        jSplitPane1.setRightComponent(jTabbedPane1);

        getContentPane().add(jSplitPane1);

        jMenu1.setText("Metadata");

        jMenuItemEditMetadata.setText("Edit Metadata...");
        jMenuItemEditMetadata.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                jMenuItemEditMetadataActionPerformed(evt);
            }
        });
        jMenu1.add(jMenuItemEditMetadata);

        jMenuBar1.add(jMenu1);

        setJMenuBar(jMenuBar1);

        pack();
    }// </editor-fold>//GEN-END:initComponents

	private void jTextPane1FocusLost(java.awt.event.FocusEvent evt)//GEN-FIRST:event_jTextPane1FocusLost
	{//GEN-HEADEREND:event_jTextPane1FocusLost
		// when the focus is going out of the text pane, update the query builder with new query text
		try
		{
			queryBuilder1.setSQL(jTextPane1.getText());
		}
		catch (QueryBuilderException ex)
		{
			Logger.getLogger(this.getClass().getName()).log(Level.SEVERE, null, ex);
			JOptionPane.showMessageDialog(this, ex.getMessage());
		}
	}//GEN-LAST:event_jTextPane1FocusLost

	private void jTextPane2FocusLost(java.awt.event.FocusEvent evt)//GEN-FIRST:event_jTextPane2FocusLost
	{//GEN-HEADEREND:event_jTextPane2FocusLost
		// when the focus is going out of the text pane, update the query builder with new query text
		try
		{
			queryBuilder1.setSQL(jTextPane2.getText());
		}
		catch (QueryBuilderException ex)
		{
			Logger.getLogger(this.getClass().getName()).log(Level.SEVERE, null, ex);
			JOptionPane.showMessageDialog(this, ex.getMessage());
		}
	}//GEN-LAST:event_jTextPane2FocusLost

	private void jMenuItemEditMetadataActionPerformed(java.awt.event.ActionEvent evt)//GEN-FIRST:event_jMenuItemEditMetadataActionPerformed
	{//GEN-HEADEREND:event_jMenuItemEditMetadataActionPerformed
		QueryBuilder.editMetadataContainer(this, queryBuilder1.getMetadataContainer(), false, queryBuilder1.getMetadataFilter());
	}//GEN-LAST:event_jMenuItemEditMetadataActionPerformed

    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JMenu jMenu1;
    private javax.swing.JMenuBar jMenuBar1;
    private javax.swing.JMenuItem jMenuItemEditMetadata;
    private javax.swing.JScrollPane jScrollPane1;
    private javax.swing.JScrollPane jScrollPane2;
    private javax.swing.JSplitPane jSplitPane1;
    private javax.swing.JTabbedPane jTabbedPane1;
    private javax.swing.JTextPane jTextPane1;
    private javax.swing.JTextPane jTextPane2;
    private com.adbs.querybuilder.QueryBuilder queryBuilder1;
    // End of variables declaration//GEN-END:variables

}
