package querymodificationdemo;

import com.adbs.ast.*;
import com.adbs.metadata.*;
import com.adbs.querybuilder.*;
import com.adbs.syntax.*;
import java.io.BufferedReader;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.util.ArrayList;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.swing.JOptionPane;


public class MainFrame extends javax.swing.JFrame
{
	private static final long serialVersionUID = 1L;

	private SQLQualifiedName customersName;
	private AstTokenIdentifier customersAlias;
	private SQLQualifiedName ordersName;
	private AstTokenIdentifier ordersAlias;
	private SQLQualifiedName joinFieldName;
	private SQLQualifiedName companyNameFieldName;
	private SQLQualifiedName orderDateFieldName;

	private DataSource customers;
	private DataSource orders;
	private CriteriaItem companyName;
	private CriteriaItem orderDate;

	private PlainTextSQLBuilder plainTextSQLBuilder1;

    public MainFrame()
	{
        initComponents();

		// center window on the desktop
		setLocationRelativeTo(null);

		//set up query builder

		queryBuilder1.setSyntaxProvider(new MSSQLSyntaxProvider());

		MetadataTreeOptions mto = queryBuilder1.getMetadataTreeOptions();
		mto.setGroupingType(ObjectsGroupingType.DatabaseSchema);
		mto.setSortingType(ObjectsSortingType.SchemaTypeName);

		// Set up the PlainTextSQLBuilder.
		// (PlainTextSQLBuilder is a component that converts plain text
		// from the output of the QueryBuilder to formatted text).

		plainTextSQLBuilder1 = new PlainTextSQLBuilder();
		plainTextSQLBuilder1.setKeywordFormat(KeywordFormat.UpperCase);
		// bind the PlainTextSQLBuilder to the instance of the QueryBuilder.
		plainTextSQLBuilder1.setQueryBuilder(queryBuilder1);

		// handle the notification from PlainTextSQLBuilder about the query text has been changed
		plainTextSQLBuilder1.addSQLUpdatedEventListener(new SQLUpdatedEventListener()
		{
			@Override
			public void sqlUpdatedEventOccurred(SQLUpdatedEvent event)
			{
				try
				{
					jTextPane1.setText(plainTextSQLBuilder1.getSQL());
				}
				catch (QueryBuilderException ex)
				{
					Logger.getLogger(MainFrame.class.getName()).log(Level.SEVERE, null, ex);
				}
			}
		});

		// Load metadata from XML file located in resources (for demonstration purposes)
		try
		{
			InputStream stream = MainFrame.class.getResourceAsStream("Northwind.xml");
			BufferedReader br = new BufferedReader(new InputStreamReader(stream));
			StringBuilder sb = new StringBuilder();
			String line = null;

			while ((line = br.readLine()) != null)
			{
				sb.append(line + "\n");
			}

			br.close();
			queryBuilder1.getMetadataContainer().loadFromXML(sb.toString());
		}
		catch (Exception ex)
		{
			Logger.getLogger(this.getClass().getName()).log(Level.SEVERE, null, ex);
			JOptionPane.showMessageDialog(this, ex.getMessage());
		}

		// prepare objects
		customersName = queryBuilder1.getSQLContext().parseQualifiedName("Northwind.dbo.Customers");
		customersAlias = queryBuilder1.getSQLContext().parseIdentifier("c");
		ordersName = queryBuilder1.getSQLContext().parseQualifiedName("Northwind.dbo.Orders");
		ordersAlias = queryBuilder1.getSQLContext().parseIdentifier("o");
		joinFieldName = queryBuilder1.getSQLContext().parseQualifiedName("CustomerId");
		companyNameFieldName = queryBuilder1.getSQLContext().parseQualifiedName("CompanyName");
		orderDateFieldName = queryBuilder1.getSQLContext().parseQualifiedName("OrderDate");
    }

    @SuppressWarnings("unchecked")
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        jScrollPane1 = new javax.swing.JScrollPane();
        jTextArea1 = new javax.swing.JTextArea();
        jTabbedPane1 = new javax.swing.JTabbedPane();
        jScrollPane2 = new javax.swing.JScrollPane();
        jTextPane1 = new javax.swing.JTextPane();
        queryBuilder1 = new com.adbs.querybuilder.QueryBuilder();
        jPanel2 = new javax.swing.JPanel();
        jPanel1 = new javax.swing.JPanel();
        jScrollPane3 = new javax.swing.JScrollPane();
        jTextArea2 = new javax.swing.JTextArea();
        cbCustomers = new javax.swing.JCheckBox();
        cbCompanyName = new javax.swing.JCheckBox();
        cbOrders = new javax.swing.JCheckBox();
        cbOrderDate = new javax.swing.JCheckBox();
        tfCompanyName = new javax.swing.JTextField();
        tfOrderDate = new javax.swing.JTextField();
        btnQueryCustomers = new javax.swing.JButton();
        btnQueryOrders = new javax.swing.JButton();
        btnQueryCustomersOrders = new javax.swing.JButton();
        btnApply = new javax.swing.JButton();

        setDefaultCloseOperation(javax.swing.WindowConstants.EXIT_ON_CLOSE);
        setTitle("Query Modification Demo");

        jTextArea1.setBackground(java.awt.SystemColor.info);
        jTextArea1.setColumns(20);
        jTextArea1.setEditable(false);
        jTextArea1.setFont(new java.awt.Font("Tahoma", 0, 11));
        jTextArea1.setLineWrap(true);
        jTextArea1.setRows(3);
        jTextArea1.setText("This sample project demonstrates ability to analyze SQL queries and modify them programmatically. This could be helpful if you want to correct erroneous queries before execution or to restrict manipulations with specific data.\nThis demo allows you to load several sample queries and see how they will be changed according to your modification settings.");
        jTextArea1.setWrapStyleWord(true);
        jTextArea1.setFocusable(false);
        jTextArea1.setMargin(new java.awt.Insets(2, 5, 2, 2));
        jScrollPane1.setViewportView(jTextArea1);

        jTextPane1.addFocusListener(new java.awt.event.FocusAdapter() {
            public void focusLost(java.awt.event.FocusEvent evt) {
                jTextPane1FocusLost(evt);
            }
        });
        jScrollPane2.setViewportView(jTextPane1);

        jTabbedPane1.addTab("SQL Query Text", jScrollPane2);
        jTabbedPane1.addTab("Query Builder", queryBuilder1);

        jPanel1.setBorder(javax.swing.BorderFactory.createTitledBorder("Modification Settings"));

        jScrollPane3.setBorder(null);

        jTextArea2.setBackground(java.awt.SystemColor.control);
        jTextArea2.setColumns(20);
        jTextArea2.setFont(new java.awt.Font("Tahoma", 0, 11));
        jTextArea2.setForeground(java.awt.SystemColor.controlDkShadow);
        jTextArea2.setRows(2);
        jTextArea2.setText("Check tables you wish to add to the query.\nCheck fields you wish to define criteria for.");
        jTextArea2.setFocusable(false);
        jScrollPane3.setViewportView(jTextArea2);

        cbCustomers.setText("Customers");
        cbCustomers.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                cbCustomersActionPerformed(evt);
            }
        });

        cbCompanyName.setText("CompanyName");
        cbCompanyName.setEnabled(false);
        cbCompanyName.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                cbCompanyNameActionPerformed(evt);
            }
        });

        cbOrders.setText("Orders");
        cbOrders.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                cbOrdersActionPerformed(evt);
            }
        });

        cbOrderDate.setText("OrderDate");
        cbOrderDate.setEnabled(false);
        cbOrderDate.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                cbOrderDateActionPerformed(evt);
            }
        });

        tfCompanyName.setText("Like 'C%'");
        tfCompanyName.setEnabled(false);

        tfOrderDate.setText("= '01/01/2007'");
        tfOrderDate.setEnabled(false);

        javax.swing.GroupLayout jPanel1Layout = new javax.swing.GroupLayout(jPanel1);
        jPanel1.setLayout(jPanel1Layout);
        jPanel1Layout.setHorizontalGroup(
            jPanel1Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel1Layout.createSequentialGroup()
                .addContainerGap()
                .addGroup(jPanel1Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING, false)
                    .addComponent(jScrollPane3, javax.swing.GroupLayout.PREFERRED_SIZE, 301, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(cbCustomers)
                    .addComponent(cbOrders)
                    .addGroup(jPanel1Layout.createSequentialGroup()
                        .addGap(21, 21, 21)
                        .addGroup(jPanel1Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                            .addComponent(cbCompanyName)
                            .addComponent(cbOrderDate))
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addGroup(jPanel1Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                            .addComponent(tfOrderDate, javax.swing.GroupLayout.DEFAULT_SIZE, 181, Short.MAX_VALUE)
                            .addComponent(tfCompanyName))))
                .addContainerGap(339, Short.MAX_VALUE))
        );
        jPanel1Layout.setVerticalGroup(
            jPanel1Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel1Layout.createSequentialGroup()
                .addComponent(jScrollPane3, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(cbCustomers)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(jPanel1Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(cbCompanyName)
                    .addComponent(tfCompanyName, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(cbOrders)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(jPanel1Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(cbOrderDate)
                    .addComponent(tfOrderDate, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addContainerGap(43, Short.MAX_VALUE))
        );

        btnQueryCustomers.setText("Load Sample Query 1");
        btnQueryCustomers.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                btnQueryCustomersActionPerformed(evt);
            }
        });

        btnQueryOrders.setText("Load Sample Query 2");
        btnQueryOrders.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                btnQueryOrdersActionPerformed(evt);
            }
        });

        btnQueryCustomersOrders.setText("Load Sample Query 3");
        btnQueryCustomersOrders.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                btnQueryCustomersOrdersActionPerformed(evt);
            }
        });

        btnApply.setText("Apply Changes");
        btnApply.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                btnApplyActionPerformed(evt);
            }
        });

        javax.swing.GroupLayout jPanel2Layout = new javax.swing.GroupLayout(jPanel2);
        jPanel2.setLayout(jPanel2Layout);
        jPanel2Layout.setHorizontalGroup(
            jPanel2Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel2Layout.createSequentialGroup()
                .addComponent(jPanel1, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
                .addGroup(jPanel2Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(btnApply, javax.swing.GroupLayout.DEFAULT_SIZE, 196, Short.MAX_VALUE)
                    .addComponent(btnQueryCustomersOrders, javax.swing.GroupLayout.DEFAULT_SIZE, 196, Short.MAX_VALUE)
                    .addComponent(btnQueryOrders, javax.swing.GroupLayout.DEFAULT_SIZE, 196, Short.MAX_VALUE)
                    .addComponent(btnQueryCustomers, javax.swing.GroupLayout.DEFAULT_SIZE, 196, Short.MAX_VALUE)))
        );
        jPanel2Layout.setVerticalGroup(
            jPanel2Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addComponent(jPanel1, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
            .addGroup(jPanel2Layout.createSequentialGroup()
                .addGap(11, 11, 11)
                .addComponent(btnQueryCustomers)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(btnQueryOrders)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(btnQueryCustomersOrders)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED, 74, Short.MAX_VALUE)
                .addComponent(btnApply, javax.swing.GroupLayout.PREFERRED_SIZE, 32, javax.swing.GroupLayout.PREFERRED_SIZE))
        );

        javax.swing.GroupLayout layout = new javax.swing.GroupLayout(getContentPane());
        getContentPane().setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, layout.createSequentialGroup()
                .addContainerGap()
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING)
                    .addComponent(jPanel2, javax.swing.GroupLayout.Alignment.LEADING, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                    .addComponent(jTabbedPane1, javax.swing.GroupLayout.Alignment.LEADING, javax.swing.GroupLayout.DEFAULT_SIZE, 868, Short.MAX_VALUE)
                    .addComponent(jScrollPane1, javax.swing.GroupLayout.Alignment.LEADING, javax.swing.GroupLayout.DEFAULT_SIZE, 868, Short.MAX_VALUE))
                .addContainerGap())
        );
        layout.setVerticalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(layout.createSequentialGroup()
                .addContainerGap()
                .addComponent(jScrollPane1, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(jTabbedPane1, javax.swing.GroupLayout.DEFAULT_SIZE, 334, Short.MAX_VALUE)
                .addGap(7, 7, 7)
                .addComponent(jPanel2, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addContainerGap())
        );

        pack();
    }// </editor-fold>//GEN-END:initComponents

	private void btnApplyActionPerformed(java.awt.event.ActionEvent evt)//GEN-FIRST:event_btnApplyActionPerformed
	{//GEN-HEADEREND:event_btnApplyActionPerformed
		UnionSubQuery usq;
		ArrayList dsList = new ArrayList();
		ArrayList dsList2 = new ArrayList();
		boolean whereFound;

		queryBuilder1.beginUpdate();

		try
		{
			// get the active SELECT
			usq = queryBuilder1.getQuery().getActiveUnionSubquery();

			usq.getFromClause().getDatasourceByClass(DataSource.class, dsList);

			// if user removed previously added datasources then clear their references
			if (customers != null && dsList.indexOf(customers) == -1)
			{
				customers = null;
			}

			if (orders != null && dsList.indexOf(orders) == -1)
			{
				orders = null;
			}

			// clear companyName conditions
			if (companyName != null && (usq.getCriteriaList().indexOf(companyName) == -1 ||
					isNullOrEmpty(companyName.getExpressionString())))
			{
				companyName = null;
			}

			if (companyName != null)
			{
				for (int i = 0; i < usq.getCriteriaList().getMaxConditionCount(); i++)
				{
					companyName.setConditionString(i, "");
				}
			}

			// clear orderDate conditions
			if (orderDate != null && (usq.getCriteriaList().indexOf(orderDate) == -1 ||
					isNullOrEmpty(orderDate.getExpressionString())))
			{
				orderDate = null;
			}

			if (orderDate != null)
			{
				for (int i = 0; i < usq.getCriteriaList().getMaxConditionCount(); i++)
				{
					orderDate.setConditionString(i, "");
				}
			}

			// process Customers table
			if (cbCustomers.isSelected())
			{
				// if we have no previously added Customers table, try to use already user added one
				if (customers == null)
				{
					usq.getFromClause().findTablesByDBName(customersName, dsList2);

					if (dsList2.size() > 0)
					{
						customers = (DataSource) dsList2.get(0);
					}
				}

				// there is no Customers table in query, add it
				if (customers == null)
				{
					customers = usq.addObject(customersName, customersAlias);
				}

				// process CompanyName condition
				if (cbCompanyName.isEnabled() && cbCompanyName.isSelected() && !isNullOrEmpty(tfCompanyName.getText()))
				{
					// if we have no previously added grid row for this condition, add it
					if (companyName == null)
					{
						companyName = usq.getCriteriaList().addField(customers, companyNameFieldName);
						companyName.setSelected(false);
					}

					// write condition from edit box to all needed grid cells
					whereFound = false;

					// GetMaxConditionCount: returns the number of non-empty criteria columns in the grid.
					for (int i = 0; i < usq.getCriteriaList().getMaxConditionCount(); i++)
					{
						// CollectCriteriaItemsWithWhereCondition:
						// This function returns the list of conditions that were found in
						// the i-th criteria column, applied to specific clause (WHERE or HAVING).
						// Thus, this function collects all conditions joined with AND
						// within one OR operator.
						collectCriteriaItemsWithWhereCondition(usq.getCriteriaList(), i, dsList2);

						if (dsList2.size() > 1 || (dsList2.size() > 0 && dsList2.get(0) != companyName))
						{
							companyName.setConditionString(i, tfCompanyName.getText());
							whereFound = true;
						}
					}

					// if there are no cells with "where" conditions, add condition to new column
					if (!whereFound)
					{
						companyName.setConditionString(usq.getCriteriaList().getMaxConditionCount(), tfCompanyName.getText());
					}
				}
				else
				{
					// remove previously added grid row
					if (companyName != null)
					{
						companyName.dispose();
					}

					companyName = null;
				}
			}
			else
			{
				// remove previously added datasource
				if (customers != null)
				{
					customers.dispose();
				}

				customers = null;
			}


			// process Orders table
			if (cbOrders.isSelected())
			{
				// if we have no previosly added Orders table, try to use already added by user
				if (orders == null)
				{
					usq.getFromClause().findTablesByDBName(ordersName, dsList2);

					if (dsList2.size() > 0)
					{
						orders = (DataSource) dsList2.get(0);
					}
				}

				// there are no Orders table in query, add one
				if (orders == null)
				{
					orders = usq.addObject(ordersName, ordersAlias);
				}

				// if we have Customers table and Orders table,
				// and there are no joins between them, create such join
				if (customers != null &&
					usq.getFromClause().findLink(orders, joinFieldName, customers, joinFieldName) == null &&
					usq.getFromClause().findLink(customers, joinFieldName, orders, joinFieldName) == null)
				{
					usq.addLink(customers, joinFieldName, orders, joinFieldName);
				}

				// process OrderDate condition
				if (cbOrderDate.isSelected() && cbOrderDate.isSelected() && !isNullOrEmpty(tfOrderDate.getText()))
				{
					if (orderDate == null)
					{
						orderDate = usq.getCriteriaList().addField(orders, orderDateFieldName);
						orderDate.setSelected(false);
					}

					// write condition from edit box to all needed grid cells
					whereFound = false;

					// GetMaxConditionsCount: returns the number of non-empty criteria columns in the grid.
					for (int i = 0; i < usq.getCriteriaList().getMaxConditionCount(); i++)
					{
						collectCriteriaItemsWithWhereCondition(usq.getCriteriaList(), i, dsList2);

						if (dsList2.size() > 1 || (dsList2.size() > 0 && dsList2.get(0) != orderDate))
						{
							orderDate.setConditionString(i, tfOrderDate.getText());
							whereFound = true;
						}
					}

					// if there are no cells with "where" conditions, add condition to new column
					if (!whereFound)
					{
						orderDate.setConditionString(usq.getCriteriaList().getMaxConditionCount(), tfOrderDate.getText());
					}
				}
				else
				{
					// remove prviously added grid row
					if (orderDate != null)
					{
						orderDate.dispose();
					}

					orderDate = null;
				}
			}
			else
			{
				if (orders != null)
				{
					orders.dispose();
					orders = null;
				}
			}
		}
		finally
		{
			queryBuilder1.endUpdate();
		}
	}//GEN-LAST:event_btnApplyActionPerformed

	private void btnQueryCustomersActionPerformed(java.awt.event.ActionEvent evt)//GEN-FIRST:event_btnQueryCustomersActionPerformed
	{//GEN-HEADEREND:event_btnQueryCustomersActionPerformed
		queryBuilder1.setSQL("select * from Northwind.dbo.Customers c");
	}//GEN-LAST:event_btnQueryCustomersActionPerformed

	private void btnQueryOrdersActionPerformed(java.awt.event.ActionEvent evt)//GEN-FIRST:event_btnQueryOrdersActionPerformed
	{//GEN-HEADEREND:event_btnQueryOrdersActionPerformed
		queryBuilder1.setSQL("select * from Northwind.dbo.Orders o");
	}//GEN-LAST:event_btnQueryOrdersActionPerformed

	private void btnQueryCustomersOrdersActionPerformed(java.awt.event.ActionEvent evt)//GEN-FIRST:event_btnQueryCustomersOrdersActionPerformed
	{//GEN-HEADEREND:event_btnQueryCustomersOrdersActionPerformed
		queryBuilder1.setSQL("select * from Northwind.dbo.Customers c, Northwind.dbo.Orders o");
	}//GEN-LAST:event_btnQueryCustomersOrdersActionPerformed

	private void cbCompanyNameActionPerformed(java.awt.event.ActionEvent evt)//GEN-FIRST:event_cbCompanyNameActionPerformed
	{//GEN-HEADEREND:event_cbCompanyNameActionPerformed
		tfCompanyName.setEnabled(cbCompanyName.isSelected());
	}//GEN-LAST:event_cbCompanyNameActionPerformed

	private void cbCustomersActionPerformed(java.awt.event.ActionEvent evt)//GEN-FIRST:event_cbCustomersActionPerformed
	{//GEN-HEADEREND:event_cbCustomersActionPerformed
		cbCompanyName.setEnabled(cbCustomers.isSelected());
		tfCompanyName.setEnabled(cbCompanyName.isSelected() && cbCustomers.isSelected());
	}//GEN-LAST:event_cbCustomersActionPerformed

	private void cbOrderDateActionPerformed(java.awt.event.ActionEvent evt)//GEN-FIRST:event_cbOrderDateActionPerformed
	{//GEN-HEADEREND:event_cbOrderDateActionPerformed
		tfOrderDate.setEnabled(cbOrderDate.isSelected());
	}//GEN-LAST:event_cbOrderDateActionPerformed

	private void cbOrdersActionPerformed(java.awt.event.ActionEvent evt)//GEN-FIRST:event_cbOrdersActionPerformed
	{//GEN-HEADEREND:event_cbOrdersActionPerformed
		cbOrderDate.setEnabled(cbOrders.isSelected());
		tfOrderDate.setEnabled(cbOrderDate.isSelected() && cbOrders.isSelected());
	}//GEN-LAST:event_cbOrdersActionPerformed

	private void jTextPane1FocusLost(java.awt.event.FocusEvent evt)//GEN-FIRST:event_jTextPane1FocusLost
	{//GEN-HEADEREND:event_jTextPane1FocusLost
		// put query text from the text pane to the Query Builder
		queryBuilder1.setSQL(jTextPane1.getText());
	}//GEN-LAST:event_jTextPane1FocusLost

	private void collectCriteriaItemsWithWhereCondition(CriteriaList criteriaList, int columnIndex, ArrayList result)
	{
		result.clear();

		for (int i = 0; i < criteriaList.getCount(); i++)
		{
			if (criteriaList.get(i).getConditionType() == ConditionType.Where &&
				criteriaList.get(i).getConditionCount() > columnIndex &&
				criteriaList.get(i).getASTCondition(columnIndex) != null)
			{
				result.add(criteriaList.get(i));
			}
		}
	}

    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JButton btnApply;
    private javax.swing.JButton btnQueryCustomers;
    private javax.swing.JButton btnQueryCustomersOrders;
    private javax.swing.JButton btnQueryOrders;
    private javax.swing.JCheckBox cbCompanyName;
    private javax.swing.JCheckBox cbCustomers;
    private javax.swing.JCheckBox cbOrderDate;
    private javax.swing.JCheckBox cbOrders;
    private javax.swing.JPanel jPanel1;
    private javax.swing.JPanel jPanel2;
    private javax.swing.JScrollPane jScrollPane1;
    private javax.swing.JScrollPane jScrollPane2;
    private javax.swing.JScrollPane jScrollPane3;
    private javax.swing.JTabbedPane jTabbedPane1;
    private javax.swing.JTextArea jTextArea1;
    private javax.swing.JTextArea jTextArea2;
    private javax.swing.JTextPane jTextPane1;
    private com.adbs.querybuilder.QueryBuilder queryBuilder1;
    private javax.swing.JTextField tfCompanyName;
    private javax.swing.JTextField tfOrderDate;
    // End of variables declaration//GEN-END:variables

	private boolean isNullOrEmpty(String s)
	{
		return (s == null || s.length() == 0);
	}
}
